%define anolis_release 2
%bcond_with tests

%{!?python3_pkgversion:%global python3_pkgversion 3}

%global srcname cryptography

Name:           python-%{srcname}
Version:        42.0.5
Release:        %{anolis_release}%{?dist}
Summary:        PyCA's cryptography library

# cryptography is dual licensed under the Apache-2.0 and BSD-3-Clause,
# as well as the Python Software Foundation license for the OS random
# engine derived by CPython.
License:        (Apache-2.0 OR BSD-3-Clause) AND PSF-2.0
URL:            https://cryptography.io/en/latest/
Source0:        https://github.com/pyca/cryptography/archive/%{version}/%{srcname}-%{version}.tar.gz
                # created by ./vendor_rust.py helper script
Source1:        cryptography-%{version}-vendor.tar.bz2
Source2:        conftest-skipper.py

Patch1:         skip-overflow-tests-32bit.patch

BuildRequires:  openssl-devel
BuildRequires:  gcc
BuildRequires:  gnupg2
BuildRequires:  rust-packaging, cargo

BuildRequires:  python%{python3_pkgversion}-cffi >= 1.12
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-setuptools-rust >= 0.11.4

%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-certifi
BuildRequires:  python%{python3_pkgversion}-pytest >= 6.2.0
BuildRequires:  python%{python3_pkgversion}-pytest-benchmark
BuildRequires:  python%{python3_pkgversion}-pytest-subtests >= 0.5.0
%endif

%description
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%package -n  python%{python3_pkgversion}-%{srcname}
Summary:        PyCA's cryptography library
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

Requires:       openssl-libs
Obsoletes: python%{python3_pkgversion}-cryptography-vectors < 3.4.7

%description -n python%{python3_pkgversion}-%{srcname}
cryptography is a package designed to expose cryptographic primitives and
recipes to Python developers.

%prep
%autosetup -p1 -N -n %{srcname}-%{version}
%autopatch -p1 1
tar -xjf %{SOURCE1}
%cargo_prep -v vendor

# Remove cosmetical pytest-subtests 0.10.0 option
sed -i 's,--no-subtests-shortletter,,' pyproject.toml


%generate_buildrequires
%pyproject_buildrequires -t

%build
export RUSTFLAGS="%build_rustflags"
export OPENSSL_NO_VENDOR=1
%pyproject_wheel


%install
# Actually other *.c and *.h are appropriate
# see https://github.com/pyca/cryptography/issues/1463
find . -name .keep -print -delete
%pyproject_install
%pyproject_save_files %{srcname}


%check
%if %{with tests}
# enable SHA-1 signatures for RSA tests
# also see https://github.com/pyca/cryptography/pull/6931 and rhbz#2060343
export OPENSSL_ENABLE_SHA1_SIGNATURES=yes

# see https://github.com/pyca/cryptography/issues/4885 and
# see https://bugzilla.redhat.com/show_bug.cgi?id=1761194 for deselected tests
# see rhbz#2042413 for memleak. It's unstable under Python 3.11 and makes
# not much sense for downstream testing.
# see rhbz#2171661 for test_load_invalid_ec_key_from_pem: error:030000CD:digital envelope routines::keymgmt export failure
PYTHONPATH=${PWD}/vectors:%{buildroot}%{python3_sitearch} \
    %{__python3} -m pytest \
    --ignore vendor \
    -k "not (test_buffer_protocol_alternate_modes or test_dh_parameters_supported or test_load_ecdsa_no_named_curve or test_decrypt_invalid_decrypt or test_openssl_memleak or test_load_invalid_ec_key_from_pem)"
%endif


%files -n python%{python3_pkgversion}-%{srcname} -f %{pyproject_files}
%doc README.rst docs
%license LICENSE LICENSE.APACHE LICENSE.BSD


%changelog
* Wed May 31 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 42.0.5-2
- rebuild for loongarch64

* Wed May 29 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 42.0.5-1
- Update to 42.0.5

* Mon Mar 25 2024 Bo Ren <rb01097748@alibaba-inc.com> - 41.0.7-2
- Rebuild with python3.11

* Wed Feb 07 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 41.0.7-1
- Update to 41.0.7

* Thu Dec 07 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 39.0.0-4
- fix CVE-2023-49083

* Tue Sep 05 2023 Funda Wang <fundawang@yeah.net> - 39.0.0-3
- fix CVE-2023-23931

* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 39.0.0-2
- Optimize the spec

* Tue Feb 14 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 39.0.0-1
- update to version 39.0.0

* Thu Sep 08 2022 happy_orange <songnannan@linux.alibaba.com> - 38.0.1-1
- update to 38.0.1

* Sun Apr 24 2022 Zhongling He <zhonglingh@linux.alibaba.com> - 36.0.2-1
- Init package from upstream v36.0.2
